@@ -22,7 +22,5 @@
 # waive the privileges and immunities granted to it by virtue of its status
 # as an Intergovernmental Organization or submit itself to any jurisdiction.
 
-
-pep257 plotextractor && \
-sphinx-build -qnNW docs docs/_build/html && \
-python setup.py test
+pycodestyle plotextractor &&\
+py.test tests
